@@ -34,6 +34,7 @@ GREEN="$(tput setaf 2)"
 YELLOW="\n$(tput setaf 3)"
 BLUE="\n$(tput setaf 4)"
 
+INSTDIR="$PWD"
 
 message () {
     # $1 : Message
@@ -96,29 +97,45 @@ check_requirements() {
 
 install_python_dependencies() {
     local PIP_CMD=$(which $PIP_NAME)
+    local PIP_VERSION="$(${PIP_CMD} --version | awk '{print $2}')"
 
     # TODO: Change for virtualenv support.
     local PIP_ARGS="install --user"
 
     # Python packages
-    local PIP_LXML="lxml"
-    local PIP_RELATORIO="relatorio"
-    local PIP_DATEUTIL="python-dateutil"
-    local PIP_PSYCOPG2="psycopg2"
-    local PIP_PYTZ="pytz>=2013b"
-    local PIP_LDAP="python-ldap"
-    local PIP_VOBJECT="vobject"
-    local PIP_PYWEBDAV="pywebdav"
-    local PIP_QRCODE="qrcode"
-    local PIP_PIL="PIL"
-    local PIP_CALDAV="caldav"
-    local PIP_POLIB="polib"
+    local PIP_LXML="lxml==3.2.3"
+    local PIP_RELATORIO="relatorio==0.6.0"
+    local PIP_DATEUTIL="python-dateutil==2.1"
+    local PIP_PSYCOPG2="psycopg2==2.5.1"
+    local PIP_PYTZ="pytz==2013.7"
+    local PIP_LDAP="python-ldap==2.4.13"
+    local PIP_VOBJECT="vobject==0.6.6"
+    local PIP_PYWEBDAV="pywebdav==0.9.8"
+    local PIP_QRCODE="qrcode==4.0.1"
+    local PIP_SIX="six==1.4.1"
+    local PIP_PIL="PIL==1.1.7"
+    local PIP_CALDAV="caldav==0.1.12"
+    local PIP_POLIB="polib==1.0.3"
 
-    local PIP_PKGS="$PIP_LXML $PIP_RELATORIO $PIP_DATEUTIL $PIP_PSYCOPG2 $PIP_PYTZ $PIP_LDAP $PIP_VOBJECT $PIP_PYWEBDAV $PIP_QRCODE $PIP_PIL $PIP_CALDAV $PIP_POLIB"
+    local PIP_PKGS="$PIP_PYTZ $PIP_LXML $PIP_RELATORIO $PIP_DATEUTIL $PIP_PSYCOPG2 $PIP_LDAP $PIP_VOBJECT $PIP_PYWEBDAV $PIP_QRCODE $PIP_SIX $PIP_PIL $PIP_CALDAV $PIP_POLIB"
+
+    message "[INFO] Installing python dependencies with pip-${PIP_VERSION} ..." ${YELLOW}
+
+    # PYTZ seems to have fixed the naming conventions issues and now is compatible with PyPI (We'll keep the code commented for a while just in case )
+    #    # Handling of BACKWARD INCOMPATIBLE arguments for pip command:
+    #    if [[ "${PIP_VERSION}" > "1.4" ]]; then
+    #        message " >> ${PIP_PYTZ} (including pre-release and development versions)" ${BLUE}
+    #        ${PIP_CMD} ${PIP_ARGS} --pre ${PIP_PYTZ} || exit 1
+    #    else
+    #        message " >> ${PIP_PYTZ}" ${BLUE}
+    #        ${PIP_CMD} ${PIP_ARGS} ${PIP_PYTZ} || exit 1
+    #    fi
+    #    message " >> OK" ${GREEN}
 
-    message "[INFO] Installing python dependencies with pip..." ${YELLOW}
     for PKG in ${PIP_PKGS}; do
+        message " >> ${PKG}" ${BLUE}
         ${PIP_CMD} ${PIP_ARGS} ${PKG} || exit 1
+        message " >> OK" ${GREEN}
     done
 }
 
@@ -148,17 +165,44 @@ install_directories() {
     TRYTON_BASEDIR="${BASEDIR}/tryton"
     TRYTOND_DIR="${TRYTON_BASEDIR}/server"
     MODULES_DIR="${TRYTOND_DIR}/modules"
-
+    LOG_DIR="${BASEDIR}/logs"
+    ATTACH_DIR="${HOME}/attach"
+    
     if [ -e ${BASEDIR} ] ; then
         message "[ERROR] Directory ${BASEDIR} exists. You need to delete it." ${RED}
         exit 1
     else
-        mkdir -p ${MODULES_DIR} ||  exit 1
+        mkdir -p ${MODULES_DIR} ${LOG_DIR} ${ATTACH_DIR} ||  exit 1
     fi
     message "[INFO] OK." ${GREEN}
 }
 
 
+bash_profile () {
+
+    message "[INFO] Creating or Updating the BASH profile for GNU Health" ${BLUE}
+
+    cd $INSTDIR
+    
+    PROFILE="$HOME/.gnuhealthrc"
+
+    if [ -e ${PROFILE} ] ; then
+        # Make a backup copy of the GNU Health BASH profile if it exists
+        message "[INFO] GNU Health BASH Profile exists. Making backup to ${PROFILE}.bak ." ${YELLOW}
+        cp ${PROFILE} ${PROFILE}.bak || exit 1
+    fi
+
+    cp gnuhealthrc ${PROFILE} ||  exit 1
+
+    # Load .gnuhealthrc from .bash_profile . If .bash_profile does not exist, create it.
+    if [ -e $HOME/.bash_profile ] ; then
+        grep --silent "source ${PROFILE}" $HOME/.bash_profile || echo "[[ -f ${PROFILE} ]] && source ${PROFILE}" >> $HOME/.bash_profile
+    else
+        echo "[[ -f ${PROFILE} ]] && source ${PROFILE}" >> $HOME/.bash_profile
+    fi
+   
+}
+
 #
 # (0) Start.
 #
@@ -278,7 +322,13 @@ message "[INFO] OK." ${GREEN}
 
 
 #
-# (8) Clean.
+# (8) BASH Profile
+#
+bash_profile
+
+
+#
+# Clean.
 #
 message "[INFO] Cleaning Up..." ${YELLOW}
 rm -rf ${TMP_DIR} || exit 1
